@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # flake8: NOQA W605
 """Pythonization of the :ref:`tmux(1)` pane.
 
@@ -6,8 +5,6 @@ libtmux.pane
 ~~~~~~~~~~~~
 
 """
-from __future__ import absolute_import, unicode_literals, with_statement
-
 import logging
 
 from . import exc
@@ -18,7 +15,7 @@ logger = logging.getLogger(__name__)
 
 class Pane(TmuxMappingObject, TmuxRelationalObject):
     """
-    A :term:`tmux(1)` :term:`Pane` [#]_.
+    A :term:`tmux(1)` :term:`Pane` [pane_manual]_.
 
     ``Pane`` instances can send commands directly to a pane, or traverse
     between linked tmux objects.
@@ -36,7 +33,7 @@ class Pane(TmuxMappingObject, TmuxRelationalObject):
     References
     ----------
 
-    .. [#] tmux pane. openbsd manpage for TMUX(1).
+    .. [pane_manual] tmux pane. openbsd manpage for TMUX(1).
            "Each window displayed by tmux may be split into one or more
            panes; each pane takes up a certain area of the display and is
            a separate terminal."
@@ -151,7 +148,7 @@ class Pane(TmuxMappingObject, TmuxRelationalObject):
         self.send_keys('reset')
 
     def reset(self):
-        """Reset and clear pane history. """
+        """Reset and clear pane history."""
 
         self.cmd('send-keys', r'-R \; clear-history')
 
